==> haskell-gtk2hs-buildtools-0.13.4.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk2hs-buildtools
version: 0.13.4.0
id: gtk2hs-buildtools-0.13.4.0-33ZbJjoA1fe4oeqLHRK9iU
key: gtk2hs-buildtools-0.13.4.0-33ZbJjoA1fe4oeqLHRK9iU
license: GPL-2.0-only
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-devel@lists.sourceforge.net
author: Axel Simon, Duncan Coutts, Manuel Chakravaty
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Tools to build the Gtk2Hs suite of User Interface libraries.
description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.
category: Development
abi: 86713e331c3ebedd5ed4ad7219b0caf0
exposed: True
exposed-modules:
    Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules: Paths_gtk2hs_buildtools BaseVersion Config Errors
                Binary DLists FastMutInt FileOps FNameOps Map Position Set UNames
                CIO State StateBase StateTrans Attributes Idents NameSpaces Lexers
                C CAST CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty
                CTokens CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader
                C2HSState Switches C2HSConfig Version
import-dirs: /usr/lib/ghc-8.4.2/site-local/gtk2hs-buildtools-0.13.4.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/gtk2hs-buildtools-0.13.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-gtk2hs-buildtools
hs-libraries: HSgtk2hs-buildtools-0.13.4.0-33ZbJjoA1fe4oeqLHRK9iU
depends:
    base-4.11.1.0 process-1.6.3.0 array-0.5.2.0 pretty-1.1.3.6
    filepath-1.4.2 random-1.1-9LLJAJa4iQFLJiLXBOBXBV Cabal-2.2.0.1
    directory-1.3.1.5 containers-0.5.11.0
    hashtables-1.2.3.0-IlGLFOhRp9KDxN69x7b4cM
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             process-1.6.3.0=f742183dfb18804fd4a4a0e3c09be01d
             array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
             pretty-1.1.3.6=003e48b94caa84f26c31da01b81a0320
             filepath-1.4.2=a70b79acbde9ca897bdc5eadf9254ba7
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=552cb76a5e53a808564c851a382c09ce
             Cabal-2.2.0.1=00dccbba264df0e70719798e8bc74c63
             directory-1.3.1.5=c4ddb2059d4b7fed7d39b1d1bb3bf41d
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             hashtables-1.2.3.0-IlGLFOhRp9KDxN69x7b4cM=9bae143ba1d337ffece44eaf3b04613c
haddock-interfaces: /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock
haddock-html: /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk2hs-buildtools-0.13.4.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gtk2hs-buildtools
version: 0.13.4.0
id: gtk2hs-buildtools-0.13.4.0-HJyAEInbHDC7MFiwgu9bgv
key: gtk2hs-buildtools-0.13.4.0-HJyAEInbHDC7MFiwgu9bgv
license: GPL-2.0-only
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-devel@lists.sourceforge.net
author: Axel Simon, Duncan Coutts, Manuel Chakravaty
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Tools to build the Gtk2Hs suite of User Interface libraries.
description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.
category: Development
abi: 2cf5f55507a628ac39d5239bcd72c0e3
exposed: True
exposed-modules:
    Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules: Paths_gtk2hs_buildtools BaseVersion Config Errors
                Binary DLists FastMutInt FileOps FNameOps Map Position Set UNames
                CIO State StateBase StateTrans Attributes Idents NameSpaces Lexers
                C CAST CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty
                CTokens CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader
                C2HSState Switches C2HSConfig Version
import-dirs: /usr/lib/ghc-8.4.2/site-local/gtk2hs-buildtools-0.13.4.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/gtk2hs-buildtools-0.13.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-gtk2hs-buildtools
hs-libraries: HSgtk2hs-buildtools-0.13.4.0-HJyAEInbHDC7MFiwgu9bgv
depends:
    base-4.11.1.0 process-1.6.3.0 array-0.5.2.0 pretty-1.1.3.6
    filepath-1.4.2 random-1.1-9LLJAJa4iQFLJiLXBOBXBV Cabal-2.2.0.1
    directory-1.3.1.5 containers-0.5.11.0
    hashtables-1.2.3.1-E6SyqzZX2cWDpE9R8x74sx
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             process-1.6.3.0=f742183dfb18804fd4a4a0e3c09be01d
             array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
             pretty-1.1.3.6=003e48b94caa84f26c31da01b81a0320
             filepath-1.4.2=a70b79acbde9ca897bdc5eadf9254ba7
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=552cb76a5e53a808564c851a382c09ce
             Cabal-2.2.0.1=00dccbba264df0e70719798e8bc74c63
             directory-1.3.1.5=c4ddb2059d4b7fed7d39b1d1bb3bf41d
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             hashtables-1.2.3.1-E6SyqzZX2cWDpE9R8x74sx=86cff079c8709efa20cd8e6904307e3d
haddock-interfaces: /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock
haddock-html: /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
